summaryrefslogtreecommitdiffstats
path: root/Doc/conf.py
diff options
context:
space:
mode:
Diffstat (limited to 'Doc/conf.py')
-rw-r--r--Doc/conf.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/Doc/conf.py b/Doc/conf.py
index d44a84e..bd098df 100644
--- a/Doc/conf.py
+++ b/Doc/conf.py
@@ -239,10 +239,11 @@ nitpick_ignore += [
# be resolved, as the method is currently undocumented. For context, see
# https://github.com/python/cpython/pull/103289.
('py:meth', '_SubParsersAction.add_parser'),
# Attributes that definitely should be documented better,
# but are deferred for now:
('py:attr', '__annotations__'),
('py:attr', '__wrapped__'),
+ ('py:meth', 'index'), # list.index, tuple.index, etc.
]
# gh-106948: Copy standard C types declared in the "c:type" domain to the
@@ -239,10 +239,11 @@ nitpick_ignore += [
# https://github.com/python/cpython/pull/103289.
('py:meth', '_SubParsersAction.add_parser'),
- # Attributes that definitely should be documented better,
+ # Attributes/methods/etc. that definitely should be documented better,
# but are deferred for now:
('py:attr', '__annotations__'),